%define anolis_release 1

Name: procps-ng
Version: 4.0.4
Release: %{anolis_release}%{?dist}
Summary: System and process monitoring utilities
License: GPL+ and GPLv2 and GPLv2+ and GPLv3+ and LGPLv2+
URL: https://sourceforge.net/projects/procps-ng/
Source0: https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz

BuildRequires: make gcc automake autoconf
BuildRequires: po4a git libtool
BuildRequires: ncurses-devel gettext-devel systemd-devel

%if %{with tests}
BuildRequires: dejagnu
%endif

Provides: procps = %{version}-%{release}
Obsoletes: procps < 4.0.1-1
# usrmove hack - will be removed once initscripts are fixed
Provides: /sbin/sysctl
Provides: /bin/ps


%description
procps is a set of command line and full-screen utilities that provide
information out of the pseudo-filesystem most commonly located at /proc.
This filesystem provides a simple interface to the kernel data structures.
The programs of procps generally concentrate on the structures that describe
the processess running on the system.

The following programs are found in procps:

- free - Report the amount of free and used memory in the system
- kill - Send a signal to a process based on PID
- pgrep - List processes based on name or other attributes
- pkill - Send a signal to a process based on name or other attributes
- pmap - Report memory map of a process
- ps - Report information of processes
- pwdx - Report current directory of a process
- skill - Obsolete version of pgrep/pkill
- slabtop - Display kernel slab cache information in real time
- snice - Renice a process
- sysctl - Read or Write kernel parameters at run-time
- tload - Graphical representation of system load average
- top - Dynamic real-time view of running processes
- uptime - Display how long the system has been running
- vmstat - Report virtual memory statistics
- w - Report logged in users and what they are doing
- watch - Execute a program periodically, showing output fullscreen

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:  System and process monitoring utilities
Requires: %{name} = %{EVR}
Provides: procps-devel = %{EVR}
Obsoletes: procps-devel < 3.3.17-8

%description devel
System and process monitoring utilities development headers for %{name}.

%package i18n
Summary:  Internationalization pack for procps-ng
Requires: %{name} = %{EVR}
BuildArch: noarch

Conflicts: man-pages-de < 1.7-3
Conflicts: man-pages-fr < 3.66-3
Conflicts: man-pages-pl < 0.7-5

%description i18n
Internationalization pack for procps-ng

%prep
%autosetup -n procps-ng-%{version} -p1

%build
# The following stuff is needed for git archives only
#echo "%{version}" > .tarball-version
#./autogen.sh

autoreconf --verbose --force --install

%configure \
           --exec-prefix=/ \
           --disable-static \
           --disable-w-from \
           --disable-kill \
           --enable-watch8bit \
           --enable-skill \
           --enable-sigwinch \
           --enable-libselinux \
           --with-systemd \
           --disable-modern-top\
           --enable-pidwait

make CFLAGS="%{optflags}"

%if %{with tests}
%check
make check
%endif

%install
%make_install

rm -rf %{buildroot}%{_mandir}/pl/man5
rm -rf %{buildroot}%{_mandir}/{fr,de,pt_BR}/man3
%find_lang %{name} --all-name --with-man
ln -s %{_bindir}/pidof %{buildroot}%{_sbindir}/pidof

%generate_compatibility_deps
%ldconfig_scriptlets

%files
%license COPYING COPYING.LIB
%doc bugs.md FAQ
%dir %{abidir}
%{_libdir}/libproc2.so.*
%{_bindir}/*
%{_sbindir}/*

%{_mandir}/man1/*
%{_mandir}/man8/*
%{_mandir}/man5/*
%{abidir}/*-option.list

%exclude %{_pkgdocdir}/libproc.supp

%files doc
%doc AUTHORS NEWS README.md

%files devel
%license COPYING COPYING.LIB
%{_libdir}/libproc2.so
%{abidir}/libproc2.dump
%{_libdir}/pkgconfig/libproc2.pc
%{_includedir}/libproc2
%{_mandir}/man3/*

%files i18n -f %{name}.lang

%changelog
* Wed Mar 13 2024 Yangxinyu <yangxinyu@nfschina.com> - 4.0.4-1
- update to 4.0.4

* Fri Aug 18 2023 Funda Wang <fundawang@yeah.net> - 3.3.17-5
- fix CVE-2023-4016

* Wed Apr 12 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 3.3.17-4
- Refactor the specfile

* Wed Jan 04 2023 happy_orange <songnannan@linux.alibaba.com> - 3.3.17-3
- add some patches and abi api files

* Wed Sep 28 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.3.17-2
- add doc package

* Wed Mar  9 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 3.3.17-1
- Init version from upstream v3.3.17
